83622932bcf25fa87958bd829eec7e6317ae4390
angie
  Mon Jan 17 11:06:53 2011 -0800
Oops, thought this was included in  31b56093: Just for fun, added HGDP world map icon to collapsible section header in SNP details.
diff --git src/hg/hgc/hgc.h src/hg/hgc/hgc.h
index b04cb99..b126dfc 100644
--- src/hg/hgc/hgc.h
+++ src/hg/hgc/hgc.h
@@ -374,31 +374,34 @@
 void customMafClick(struct sqlConnection *conn, 
 	struct sqlConnection *conn2, struct trackDb *tdb);
 /* handle clicks on a custom maf */
 
 void doEncodePeak(struct trackDb *tdb, struct customTrack *ct);
 /*  details for encodePeak type tracks.  */
 
 void doEncodeFiveC(struct sqlConnection *conn, struct trackDb *tdb);
 /* Print details for 5C track */
 
 void doHgdpGeo(struct trackDb *tdb, char *item);
 /* Show details page for HGDP SNP with population allele frequencies
  * plotted on a world map. */
 
 void hgdpGeoImg(struct hgdpGeo *geo);
-/* Generate a PNG image: world map with pie charts for population allele frequencies. */
+/* Generate image as PNG, PDF, EPS: world map with pie charts for population allele frequencies. */
+
+char *hgdpPngFilePath(char *rsId);
+/* Return the stable PNG trash-cached image path for rsId. */
 
 void hgdpGeoFreqTable(struct hgdpGeo *geo);
 /* Print an HTML table of populations and allele frequencies. */
 
 void printCustomUrl(struct trackDb *tdb, char *itemName, boolean encode);
 /* Wrapper to call printCustomUrlWithLabel using the url setting in trackDb */
 
 void doBamDetails(struct trackDb *tdb, char *item);
 /* Show details of an alignment from a BAM file. */
 
 void doMakeItemsDetails(struct customTrack *ct, char *itemIdString);
 /* Show details of a makeItems item. */
 
 void doBedDetail(struct trackDb *tdb, struct customTrack *ct, char *itemName);
 /* generate the detail page for a custom track of bedDetail type */